@@ -5,7 +5,7 @@ import imp
 import fnmatch
 import logging
 
-VERSION = (0, 2, None)
+VERSION = (0, 2, 1)
 
 default_plugin_path = os.path.join(os.environ['HOME'], '.plugpy/plugins')
 
@@ -19,7 +19,8 @@ def setup_log():
     global logger
     logger = logging.getLogger(__name__)
     hdlr = logging.StreamHandler(sys.stdout)
-    formatter = logging.Formatter('%(asctime)s %(name)-12s %(levelname)-8s %(message)s')
+    formatter = logging.Formatter('%(asctime)s %(name)-12s %(levelname)-8s %(message)s',
+                '%Y-%m-%d %H:%M:%S')
     hdlr.setFormatter(formatter)
     logger.addHandler(hdlr)
     logger.setLevel(logging.DEBUG)
@@ -152,16 +153,18 @@ def load_plugins(config, plugin_path=None, plugin_class=None,
 
 def dispatch(message, *args, **kwargs):
     res = []
-    clazz = kwargs.get('target', Plugin)
-    prefix = kwargs.get('prefix', 'on_')
+    clazz = kwargs.pop('target', Plugin)
+    prefix = kwargs.pop('prefix', 'on_')
     attr = prefix + message
     log("dispatch send message:'%s' call_method: '%s'" % (message, attr))
     targets = []
-    try:
+    if clazz in _cache:
         targets = _cache[clazz]
+        log("dipatch targets %s" % targets)
         for ins in targets:
-            try:
+            if hasattr(ins, attr):
                 func = getattr(ins, attr)
+                log("find method %s '%s'" % (attr, ins))
                 if func.im_func.func_code.co_argcount > 1:
                     result = func(*args, **kwargs)
                 else:
@@ -169,10 +172,9 @@ def dispatch(message, *args, **kwargs):
                 log("dispatch to %s call_method '%s' arg_info: %s %s : result %s" % 
                         (ins, attr, args, kwargs, result ))
                 res.append((result, ins.__class__))
-            except AttributeError:
+            else:
                 log("missing plugin '%s' method '%s'" % (clazz, attr))
-                pass
-    except KeyError:
+    else:
         log("missing plugin '%s'" % clazz)
         return
     
